@@ -4,6 +4,7 @@ from .models import (
     CreateDataSourceModel,
     CheckAccessModel,
     CheckMultipleAccessModel,
+    FgaObjectModel
 )
 
 __all__ = [
@@ -12,6 +13,7 @@ __all__ = [
     "CreateDataSourceModel",
     "CheckAccessModel",
     "CheckMultipleAccessModel",
+    "FgaObjectModel"
 ]
-__version__ = "0.2.3"
+__version__ = "0.2.5"
 __author__ = "IntelliOps"
