@@ -32,9 +32,14 @@ class DummyHttpClient:
         elif url in ("confluence/create-l1-l2-objects", "/confluence/create-l1-l2-objects"):
             return DummyResponse(200)
         elif url in ("access/check", "/access/check"):
-            # Return False for a specific fgaObjectId to test negative case
-            if json and json.get("objectId") == "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045":
-                return DummyResponse(200, {"hasAccess": False})
+            # Return False for a specific fgaObject.objectId to test negative case
+            if json:
+                # Support both old and new payloads for robustness
+                object_id = json.get("objectId")
+                if not object_id and "fgaObject" in json and isinstance(json["fgaObject"], dict):
+                    object_id = json["fgaObject"].get("objectId")
+                if object_id == "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045":
+                    return DummyResponse(200, {"hasAccess": False})
             return DummyResponse(200, {"hasAccess": True})
         elif url in ("auth/sync", "/auth/sync"):
             return DummyResponse(200)
@@ -83,9 +88,13 @@ def test_init_fga_http_error(monkeypatch):
 def test_check_access_true():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyHttpClient()
+    from intelliopsopenfgasdk_python.models import FgaObjectModel
     model = CheckAccessModel(
         intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        fgaObject=FgaObjectModel(
+            intelliopsConnectorUId="connector",
+            objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        )
     )
     assert sdk.check_access(model) is True
 
@@ -93,9 +102,13 @@ def test_check_access_true():
 def test_check_access_false():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyHttpClient()
+    from intelliopsopenfgasdk_python.models import FgaObjectModel
     model = CheckAccessModel(
         intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
+        fgaObject=FgaObjectModel(
+            intelliopsConnectorUId="connector",
+            objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
+        )
     )
     assert sdk.check_access(model) is False
 
@@ -201,9 +214,13 @@ def test_async_check_access_true():
             return DummyResponse(200, {"hasAccess": True})
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClient()
+    from intelliopsopenfgasdk_python.models import FgaObjectModel
     model = CheckAccessModel(
         intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        fgaObject=FgaObjectModel(
+            intelliopsConnectorUId="connector",
+            objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        )
     )
     result = asyncio.run(sdk.async_check_access(model))
     assert result is True
@@ -216,9 +233,13 @@ def test_async_check_access_false():
             return DummyResponse(200, {"hasAccess": False})
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClient()
+    from intelliopsopenfgasdk_python.models import FgaObjectModel
     model = CheckAccessModel(
         intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
+        fgaObject=FgaObjectModel(
+            intelliopsConnectorUId="connector",
+            objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
+        )
     )
     result = asyncio.run(sdk.async_check_access(model))
     assert result is False
@@ -228,24 +249,24 @@ def test_check_multi_access():
     class DummyHttpClientMulti(DummyHttpClient):
         def post(self, url, json=None):
             if url in ("access/multi-check", "/access/multi-check"):
+                # Return the correct structure expected by the SDK: {"results": [ ... ]}
                 return DummyResponse(200, {
-                    "results": {
-                        "results": [
-                            {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177", "hasAccess": True},
-                            {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453", "hasAccess": False},
-                            {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451", "hasAccess": True}
-                        ]
-                    }
+                    "results": [
+                        {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177", "hasAccess": True},
+                        {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453", "hasAccess": False},
+                        {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451", "hasAccess": True}
+                    ]
                 })
             return super().post(url, json)
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyHttpClientMulti()
+    from intelliopsopenfgasdk_python.models import FgaObjectModel
     model = CheckMultipleAccessModel(
         intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        fgaObjectIds=[
-            "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177",
-            "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453",
-            "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        fgaObjects=[
+            FgaObjectModel(intelliopsConnectorUId="connector", objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177"),
+            FgaObjectModel(intelliopsConnectorUId="connector", objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453"),
+            FgaObjectModel(intelliopsConnectorUId="connector", objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"),
         ]
     )
     result = sdk.check_multi_access(model)
@@ -261,25 +282,25 @@ def test_async_check_multi_access():
     class DummyAsyncHttpClientMulti(DummyHttpClient):
         async def async_post(self, url, json=None):
             if url in ("access/multi-check", "/access/multi-check"):
+                # Return the correct structure expected by the SDK: {"results": [ ... ]}
                 return DummyResponse(200, {
-                    "results": {
-                        "results": [
-                            {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177", "hasAccess": True},
-                            {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453", "hasAccess": False},
-                            {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451", "hasAccess": True}
-                        ]
-                    }
+                    "results": [
+                        {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177", "hasAccess": True},
+                        {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453", "hasAccess": False},
+                        {"l2object": "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451", "hasAccess": True}
+                    ]
                 })
             # Fallback for other endpoints
             return DummyResponse(404)
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClientMulti()
+    from intelliopsopenfgasdk_python.models import FgaObjectModel
     model = CheckMultipleAccessModel(
         intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        fgaObjectIds=[
-            "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177",
-            "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453",
-            "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        fgaObjects=[
+            FgaObjectModel(intelliopsConnectorUId="connector", objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177"),
+            FgaObjectModel(intelliopsConnectorUId="connector", objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453"),
+            FgaObjectModel(intelliopsConnectorUId="connector", objectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"),
         ]
     )
     result = asyncio.run(sdk.async_check_multi_access(model))
